{% extends "paano/base.html" %}

{% block paano_content %}
<h2>{{ category.title }}</h2>
{% if current_user.is_authenticated() %}
<p>
    <a class="paano-edit" href="{{ category.url(edit=1) }}">Edit</a> &ndash;
    <a class="paano-delete" href="{{ category.url() }}">Delete</a>
</p>
{% endif %}
<ul class="questions">
{% for question in questions %}
    <li>
        <a href="{{ question.url() }}">{{ question.title }}</a>
    </li>
{% endfor %}
</ul>
{% endblock %}
