.cf:before,
.cf:after {
    content: " "; /* 1 */
    display: table; /* 2 */
}

.cf:after {
    clear: both;
}

/**
 * For IE 6/7 only
 * Include this rule to trigger hasLayout and contain floats.
 */
.cf {
    *zoom: 1;
}

a {
    color: dodgerblue;
    text-decoration: none;
}

h2, h3, h4, h5 {
    line-height: 32px;
    margin: 0 0 16px 0;
}

h1 {
    line-height: 32px;
    margin: 0;
}

h1 a {
    color: #333;
}

body,
input,
textarea,
select {
    font: 16px/24px Helvetica, Arial, sans-serif;
    color: #333;
}

input[type=text],
textarea {
    border: 1px solid gray;
    border-radius: 3px;
    padding: 4px 5px;
}

input, select {
    vertical-align: middle;
}

input[type=button],
input[type=submit],
button {
    border: 1px solid gray;
    border-radius: 3px;
    background-color: #d5d5d5;
    text-shadow: 1px 1px 0 white;
    line-height: 24px;
    padding: 0 10px;
    margin: 4px 0;
}

label {
    font-size: 125%;
    font-weight: bold;
    display: block;
    line-height: 32px;
}

p {
    margin: 0 0 16px 0;
}

input[type=button],
input[type=submit],
button,
.beveled {
    box-shadow: inset 0 1px 0 rgba(255, 255, 255, 0.8),
    inset 0 -1px rgba(0, 0, 0, 0.1);
}

#wrapper {
    margin: 20px 40px;
}

#messages {
    position: absolute;
    width: 100%;
    top: -2px;
}

#messages ul {
    text-align: center;
    list-style: none;
    margin: 0;
    padding: 0;
}

#messages li {
    display: block;
    margin-bottom: 16px;
}

#messages ul li span {
    display: inline-block;
    background-color: gold;
    padding: 0 10px;
    line-height: 24px;
    border-radius: 3px;
    border: 1px solid goldenrod;
    text-shadow: 1px 1px 0 white;
}

#page {
    background-color: #eee;
    border: 1px solid #d5d5d5;
    border-radius: 3px;
}

#sidebar {
    float: left;
    width: 220px;
    padding: 16px 0 16px 20px;
    text-shadow: 1px 1px 0 white;
}

#content {
    background-color: white;
    border: 1px solid #d5d5d5;
    border-width: 0 0 1px 1px;
    padding: 16px 20px;
    margin-left: 240px;
}

#content h2 a {
    color: #333;
}

#platform {
    float: right;
}

#footer {
    margin-top: 32px;
}

#sidebar ul,
.questions {
    list-style: none;
    margin: 0 0 16px 10px;
    padding: 0;
}

#sidebar ul {
    line-height: 24px;
}

.questions {
    font-size: 125%;
    line-height: 32px;
}