{% extends "paano/base.html" %}

{% block paano_content %}
<h2><a href="{{ category.url() }}">{{ category.title }}</a> &rsaquo; {{ question.title }}</h2>
{% if current_user.is_authenticated() %}
<p>
    <a class="paano-edit" href="{{ question.url(edit=1) }}">Edit</a> &ndash;
    <a class="paano-delete" href="{{ question.url() }}">Delete</a> &ndash;
    <a class="paano-fork" href="{{ url_for('new_question', category_id=category.id, eid=question.eid) }}">Fork</a>
</p>
{% endif %}
{{ m.html(question.content) | safe }}
{% endblock %}
