ALLOWED_EXTS = set(['.png', '.jpg', '.jpeg', '.gif'])
DEFAULT_LANG = 'en'
AVAILABLE_LANGS = [
    ('en', 'English'),
    ]
DEFAULT_PLATFORM = 'general'
AVAILABLE_PLATFORMS = [
    ('general', 'General'),
    ('win', 'Windows'),
    ('mac', 'Mac'),
    ('linux', 'Linux'),
    ]
